@@ -1,9 +1,10 @@
 """ boris.api
 
-    The boris.api module provides TODO @igor
+    The boris.api module provides access to the WhatToLabel web-app.
 """
 
 from ._communication import get_presigned_upload_url
 from ._helpers import upload_images_from_folder
 from ._helpers import upload_file_with_signed_url
 from ._helpers import upload_embeddings_from_csv
+from ._helpers import get_samples_by_tag
