@@ -4,7 +4,7 @@ import random
 import requests
 
 SERVER_LOCATION = os.getenvb(b'BORIS_SERVER_LOCATION',
-                             b'https://api-dev.whattolabel.com').decode()
+                             b'https://api.whattolabel.com').decode()
 
 
 def _post_request(dst_url, data=None, json=None,
@@ -71,6 +71,38 @@ def _put_request(dst_url, data,
     return response
 
 
+def _get_request(dst_url, params=None,
+                 max_backoff=32, max_retries=5):
+
+    counter = 0
+    backoff = 1. + random.random() * 0.1
+    success = False
+    while not success:
+
+        response = requests.get(dst_url, params=params)
+        success = (response.status_code == 200)
+
+        # exponential backoff
+        if response.status_code in [500, 502]:
+            time.sleep(backoff)
+            backoff = 2*backoff if backoff < max_backoff else backoff
+        # something went wrong
+        elif not success:
+            msg = f'Failed GET request to {dst_url} with status_code '
+            msg += f'{response.status_code}.'
+            raise RuntimeError(msg)
+
+        counter += 1
+        if counter >= max_retries:
+            break
+
+    if not success:
+        msg = f'The connection to the server at {dst_url} timed out. '
+        raise RuntimeError(msg)
+
+    return response
+
+
 def create_initial_tag(dataset_id: str, token: str):
     """Makes empty post request to dataset to create initial tag
 
@@ -155,3 +187,33 @@ def upload_embedding(data: dict) -> bool:
     dst_url = f'{SERVER_LOCATION}/users/datasets/{dataset_id}/embeddings'
     response = _post_request(dst_url, json=payload)
     return response
+
+
+def get_samples(dataset_id: str,
+                token: str,
+                tag_name: str = 'initial-tag'):
+    # payload is the same for both requests
+    payload = {
+        'token': token
+    }
+
+    # get tag_id
+    dst_url = f'{SERVER_LOCATION}/users/datasets/{dataset_id}/tags/'
+    response = _get_request(dst_url, params=payload)
+    tag_ids = [t['_id'] for t in response.json() if t['name'] == tag_name]
+    if len(tag_ids) == 0:
+        msg = f'No tag with name {tag_name} found '
+        msg += f'for datset with id {dataset_id}'
+        raise RuntimeError(msg)
+    elif len(tag_ids) > 1:
+        msg = f'{len(tag_ids)} tags with name {tag_name} founr '
+        msg += f'for dataset with id {dataset_id}'
+        raise RuntimeError(msg)
+    tag_id = tag_ids[0]
+
+    # get files in tag
+    dst_url = f'{SERVER_LOCATION}/users/datasets/'
+    dst_url += f'{dataset_id}/tags/{tag_id}/download'
+
+    response = _get_request(dst_url, params=payload)
+    return response.text.splitlines()
