@@ -4,11 +4,13 @@ import os
 import pandas as pd
 
 from itertools import islice
+from typing import List
 
 from boris.api._communication import create_initial_tag
 from boris.api._communication import get_presigned_upload_url
 from boris.api._communication import upload_file_with_signed_url
 from boris.api._communication import upload_embedding
+from boris.api._communication import get_samples
 from boris.data import BorisDataset
 from boris.utils import pandas_to_dict
 
@@ -92,7 +94,7 @@ def upload_images_from_folder(path_to_folder: str,
         success = True
         # try to get signed url
         try:
-            basename = os.path.basename(fname)
+            basename = fname
             signed_url = get_presigned_upload_url(
                 basename, dataset_id, token
             )
@@ -136,3 +138,62 @@ def upload_metadata_from_json(path_to_embeddings: str,
                               dataset_id: str,
                               token: str):
     pass
+
+
+def get_samples_by_tag(tag_name: str,
+                       dataset_id: str,
+                       token: str,
+                       mode: str = 'list',
+                       filenames: List[str] = None):
+    """Get the files associated with a given tag and dataset
+
+    Args:
+        tag_name: Name of the tag to query
+        dataset_id: The unique identifier of the dataset
+        token: Token for authentication
+        mode: Return type, must be in ["list", "mask", "indices"]
+        filenames: List of all filenames
+
+    Returns:
+        Either list of filenames, binary mask, or list of indices
+        specifying the samples in the requested tag
+
+    Raises: ValueError, RuntimeError
+
+    """
+
+    if mode == 'mask' and filenames is None:
+        msg = f'Argument filenames must not be None for mode "{mode}"!'
+        raise ValueError(msg)
+    if mode == 'indices' and filenames is None:
+        msg = f'Argument filenames must not be None for mode "{mode}"!'
+        raise ValueError(msg)
+
+    samples = get_samples(dataset_id, token, tag_name=tag_name)
+
+    if mode == 'list':
+        return samples
+
+    if mode == 'mask':
+        mask = [1 if f in set(samples) else 0 for f in filenames]
+        if sum(mask) != len(samples):
+            msg = 'Error during mapping from samples to filenames: '
+            msg += f'sum(mask) != len(samples) with lengths '
+            msg += f'{sum(mask)} and {len(samples)}'
+            raise RuntimeError(msg)
+        return mask
+
+    if mode == 'indices':
+        indices = [i for i in range(len(filenames))]
+        indices = filter(lambda i: filenames[i] in set(samples), indices)
+        indices = list(indices)
+        if len(indices) != len(samples):
+            msg = 'Error during mapping from samples to filenames: '
+            msg += f'len(indices) != len(samples) with lengths '
+            msg += f'{len(indices)} and {len(samples)}.'
+            raise RuntimeError(msg)
+        return indices
+
+    msg = f'Got illegal mode "{mode}"! '
+    msg += 'Must be in ["list", "mask", "indices"]'
+    raise ValueError(msg)
